@@ -22,7 +22,6 @@ STREAMS = {
         'data_key': 'accounts',
         'key_properties': ['sid'],
         'replication_method': 'FULL_TABLE',  # Fetch ALL, filter results
-        'replication_keys': ['date_updated'],
         'params': {},
         'pagingation': 'root',
         'children': {
@@ -44,7 +43,7 @@ STREAMS = {
                     'dependent_phone_numbers': {
                         'api_url': 'https://api.twilio.com',
                         'api_version': '2010-04-01',
-                        'path': 'Accounts/{ParentId}/Addresses/{ParentId}/DependentPhoneNumbers.json',
+                        'path': 'Accounts/{AccountSid}/Addresses/{ParentId}/DependentPhoneNumbers.json',
                         'data_key': 'dependent_phone_numbers',
                         'key_properties': ['sid'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Address
@@ -74,6 +73,7 @@ STREAMS = {
                 'api_version': '2010-04-01',
                 'path': 'Accounts/{ParentId}/AvailablePhoneNumbers.json',
                 'data_key': 'countries',
+                'sub_resource_key': 'available_phone_numbers',
                 'key_properties': ['country_code'],
                 'replication_method': 'FULL_TABLE',
                 'params': {},
@@ -86,6 +86,7 @@ STREAMS = {
                         'api_version': '2010-04-01',
                         'path': 'Accounts/{AccountSid}/AvailablePhoneNumbers/{ParentId}/Local.json',
                         'data_key': 'available_phone_numbers',
+                        'sub_resource_key': 'local',
                         'key_properties': ['iso_country', 'phone_number'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Address
                         'params': {},
@@ -99,6 +100,7 @@ STREAMS = {
                         'api_version': '2010-04-01',
                         'path': 'Accounts/{AccountSid}/AvailablePhoneNumbers/{ParentId}/Mobile.json',
                         'data_key': 'available_phone_numbers',
+                        'sub_resource_key': 'mobile',
                         'key_properties': ['iso_country', 'phone_number'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Address
                         'params': {},
@@ -112,6 +114,7 @@ STREAMS = {
                         'api_version': '2010-04-01',
                         'path': 'Accounts/{AccountSid}/AvailablePhoneNumbers/{ParentId}/TollFree.json',
                         'data_key': 'available_phone_numbers',
+                        'sub_resource_key': 'toll_free',
                         'key_properties': ['iso_country', 'phone_number'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Address
                         'params': {},
@@ -154,7 +157,7 @@ STREAMS = {
                 'data_key': 'calls',
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',  # Filter query
-                'replication_keys': ['end_time'],
+                'replication_keys': ['date_updated'],
                 'bookmark_query_field_from': 'EndTime>',  # Daily
                 'bookmark_query_field_to': 'EndTime<',
                 'params': {},
@@ -180,8 +183,9 @@ STREAMS = {
                     'conference_participants': {
                         'api_url': 'https://api.twilio.com',
                         'api_version': '2010-04-01',
-                        'path': 'Accounts/{ParentId}/Conferences/{ParentId}/Participants.json',
+                        'path': 'Accounts/{AccountSid}/Conferences/{ParentId}/Participants.json',
                         'data_key': 'participants',
+                        'sub_resource_key': 'participants',
                         'key_properties': ['uri'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Conference
                         'params': {},
@@ -252,7 +256,7 @@ STREAMS = {
                 'data_key': 'messages',
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',  # Filter query
-                'replication_keys': ['date_sent'],
+                'replication_keys': ['date_updated'],
                 'bookmark_query_field_from': 'DateSent>',  # Daily
                 'bookmark_query_field_to': 'DateSent<',
                 'params': {},
@@ -265,6 +269,7 @@ STREAMS = {
                         'api_version': '2010-04-01',
                         'path': 'Accounts/{AccountSid}/Messages/{ParentId}/Media.json',
                         'data_key': 'media_list',
+                        'sub_resource_key': 'media',
                         'key_properties': ['sid'],
                         'replication_method': 'FULL_TABLE',  # ALL for parent Address
                         'params': {},
@@ -282,8 +287,8 @@ STREAMS = {
                 'key_properties': ['account_sid', 'category', 'start_date'],
                 'replication_method': 'INCREMENTAL',  # Filter query
                 'replication_keys': ['end_date'],
-                'bookmark_query_field_from': 'StartDate',  # Daily
-                'bookmark_query_field_to': 'EndDate',
+                'bookmark_query_field_from': 'start_date',  # Daily
+                'bookmark_query_field_to': 'end_date',
                 'params': {},
                 'pagingation': 'root'
             },
@@ -313,8 +318,8 @@ STREAMS = {
         'key_properties': ['sid'],
         'replication_method': 'INCREMENTAL',  # Filter query
         'replication_keys': ['date_updated'],
-        'bookmark_query_field_from': 'StartDate',  # Bookmark
-        'bookmark_query_field_to': 'EndDate',  # Current Date
+        'bookmark_query_field_from': 'start_date',  # Bookmark
+        'bookmark_query_field_to': 'end_date',  # Current Date
         'max_days_ago': 30,
         'params': {},
         'pagingation': 'meta'
